@@ -65,11 +65,8 @@ def sync_get(path, params=None, base_url=tornado.options.options.data_server, re
 def sync_post(path, data=None,
               base_url=tornado.options.options.data_server,
               result_type="json", pack=False, **kwargs):
-    flag = kwargs.pop("flag", True)
-    if flag:
-        res = requests.post(base_url + path, json=data, **kwargs)
-    else:
-        res = requests.post(base_url + path, data=data, **kwargs)
+    kwargs.pop("flag", True)
+    res = requests.post(base_url + path, data=data, **kwargs)
     if result_type == "json":
         res = res.json()
         if not pack:
@@ -86,6 +83,7 @@ def eureka_request(path="", return_type="json", method="GET", data=None, app_nam
         kwargs.update({"headers": {
             "Content-Type": "application/json"
         }})
+    kwargs.pop("flag", True)
     res = eureka_client.do_service(app_name=app_name, service=path, return_type=return_type, method=method, data=data,
                                    **kwargs)
     if return_type == "json" and not pack:
